using System;
using System.Collections.Generic;
using System.Linq;
using System.Web;
using System.Web.Mvc;


using DHTMLX.Scheduler;
using DHTMLX.Common;
using DHTMLX.Scheduler.Data;
using DHTMLX.Scheduler.Controls;
using DropdownHeader.Models;
namespace DropdownHeader.Controllers
{
    public class CalendarController : Controller
    {
        public ActionResult Index()
        {
            var scheduler = new DHXScheduler(this);
            var context = new CalendarDataContext();

            scheduler.Lightbox.AddDefaults();
            var combo = new LightboxSelect("title_id", "Title");
            combo.AddOptions(context.Titles.ToList());
            scheduler.Lightbox.Add(combo);

            scheduler.BeforeInit.Add("initTemplates()");

            scheduler.Config.multi_day = true;

            scheduler.LoadData = true;
            scheduler.EnableDataprocessor = true;

            return View(scheduler);
        }

        public ContentResult Data()
        {
            var data = new SchedulerAjaxData(
                   new CalendarDataContext().Events
                );
            return (ContentResult)data;
        }

        public ContentResult Save(int? id, FormCollection actionValues)
        {
            var action = new DataAction(actionValues);
            
            try
            {
                var changedEvent = (Event)DHXEventsHelper.Bind(typeof(Event), actionValues);
                var context = new CalendarDataContext();
     

                switch (action.Type)
                {
                    case DataActionTypes.Insert:
                        context.Events.InsertOnSubmit(changedEvent);
                        break;
                    case DataActionTypes.Delete:
                        context.Events.DeleteOnSubmit(context.Events.Single(e => e.id == changedEvent.id));
                        break;
                    default:// "update"
                        var ev = context.Events.Single(e => e.id == changedEvent.id);
                        DHXEventsHelper.Update(ev, changedEvent, new List<string> { "id" });
                        break;
                }
                context.SubmitChanges();
                action.TargetId = changedEvent.id;
            }
            catch
            {
                action.Type = DataActionTypes.Error;
            }
            return (ContentResult)new AjaxSaveResponse(action);
        }
    }
}

